# -*- coding: utf-8 -*-
#!/usr/bin/python3

import configparser
import re
import os.path

###################################################################################
#
#  計算用のインプットファイルを読み込むためのクラス
#
###################################################################################
class INPUT(object):

    #-------------------------------------------------------------------
    # インプットファイルの読み込み
    #-------------------------------------------------------------------
    def __init__(self, input_file):
        ''' 初期化を行います．'''

        # --- 入力ファイルのチェックと設定 ---
        self.input_file = input_file
        if not(os.path.isfile(self.input_file)):
            print('\nThere is no input file !!!')
            print('\tinput file: {0:s}'.format(self.input_file))
            exit()
        self.input_file_name = os.path.basename(input_file)
        self.input_abs_dir   = os.path.dirname(os.path.abspath(input_file))
        (self.input_file_name_wo_ext, file_ext) = os.path.splitext(self.input_file_name)

        # --- ファイルの読み込み ---
        self.config = configparser.ConfigParser(inline_comment_prefixes=('#', ';'))
        self.config.optionxform = str                # キーの大文字/小文字を区別
        self.config.read(self.input_file)            # データの読み込み

        # --- 読み込んだデータを格納する辞書の初期化 ---
        self.files   = {'input_file_path': input_file}
        self.html    = {}
        self.command = {}
    
        # --- 読み込んだデータの辞書への格納 ---
        self.set_html()
        self.set_command()



    #-------------------------------------------------------------------
    # [html] のデータを設定
    #-------------------------------------------------------------------
    def set_html(self):
        ''' [html] のデータを設定 '''
        section = 'html'
        for key in self.config[section]:
            if key in ('col_width'):
                dat = self.config[section][key].split(self.config['html']['delimit'])
                self.html[key] = {'command': dat[0].strip(),\
                                  'output':  dat[1].strip(),\
                                  'space':   dat[2].strip()}
            elif key in ('svg_size'):
                dat = self.config[section][key].split(self.config['html']['delimit'])
                self.html[key] = {'width':  dat[0].strip(),\
                                  'height': dat[1].strip()}
            elif key in ('ncolumn'):
                self.html[key] = int(self.config[section][key])
            else:
                self.html[key] = self.config[section][key]

        
    #-------------------------------------------------------------------
    # [command] を設定
    #-------------------------------------------------------------------
    def set_command(self):
        ''' [command] を設定 '''
        para_list = ['height', 'TeX', 'output']
        for key, value in self.config['command'].items():
            i = int(key)
            self.command[i] = {}
            paras = re.split(self.config['html']['delimit'], value)
            paras = [paras[i].strip() for i in range(0, len(paras))]
            if len(paras) != 3:
                print('Error at READ_INPUT.py > set_command')
                exit()
            self.command[i] = {para_list[0]: paras[0],\
                               para_list[1]: paras[1],\
                               para_list[2]: paras[2]}


    #-------------------------------------------------------------------
    # インプットファイルのセクションとキー，値を表示する
    #-------------------------------------------------------------------
    def print_input_data(self):
        ''' インプットファイルのセクションとキー，値を表示する '''
        for section in config.sections():
            print([{0:s}].format(section))
            for key in config[section]:
                print('\t{0:s}'.format(config[section][key]))
                

    #-------------------------------------------------------------------
    # インプットデータを返す
    #-------------------------------------------------------------------
    def get_input_datas(self):
        ''' インプットデータを返す '''
        data = {'file': self.files,\
                'html': self.html,\
                'command': self.command}
        return data
